package com.chinaitop.agile.controller;

import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.model.DataKcglKcswDefault;
import com.chinaitop.agile.service.CrkRecordService;
import com.chinaitop.utils.ParameterMapUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 出入库记录控制类
 *
 * @author xueenxi
 */
@RestController
@RequestMapping(value = "/crkRecord")
@Api(value = "CrkRecordController", description = "出入库记录控制类")
public class CrkRecordController {

    @Resource
    private CrkRecordService crkRecordService;

    @RequestMapping(value = "/getQcCrkPageList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "汽车出入库记录查询", notes = "汽车出入库记录查询，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "cazylx", value = "业务类型", paramType = "query"),
            @ApiImplicitParam(name = "pz", value = "品种 ", paramType = "query"),
            @ApiImplicitParam(name = "beginDate", value = "开始日期 ", paramType = "query"),
            @ApiImplicitParam(name = "endDate", value = "截止日期 ", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓号", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位号 ", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query"),
            @ApiImplicitParam(name = "kqbm", value = "库区编码", paramType = "query"),
            @ApiImplicitParam(name = "housename", value = "仓房名称", paramType = "query"),
            @ApiImplicitParam(name = "mxpz", value = "明细品种编码", paramType = "query"),
            @ApiImplicitParam(name = "cphm", value = "车牌号", paramType = "query"),
            @ApiImplicitParam(name = "lsxz", value = "粮食性质编码", paramType = "query"),
            @ApiImplicitParam(name = "scnf", value = "生产年份", paramType = "query")
    })
    public PageInfo<Map<String, Object>> getQcCrkPageList(Integer pageNum, Integer pageSize,String cazylx, String pz,
            String beginDate, String endDate, String houseId,String warehouseId, Integer orgId, String kqbm, String housename, 
            String mxpz, String cphm, String lsxz, String scnf) {

    	PageInfo<Map<String, Object>> pageInfo = null;
        try {
			if (pageNum != null && pageSize != null) {
				PageHelper.startPage(pageNum, pageSize);
			}
			List<Map<String, Object>> list = crkRecordService.queryQcCrkrecord(cazylx, pz, beginDate, endDate, 
					houseId, warehouseId, orgId, kqbm, housename, mxpz, cphm, lsxz, scnf);

			pageInfo = new PageInfo<Map<String, Object>>(list);
			List<Map<String, Object>> page_list = ParameterMapUtil.slashCapitals(pageInfo.getList());
			pageInfo.setList(page_list);
		} catch (Exception e) {
			e.printStackTrace();
		}
        return pageInfo;
    }

    @RequestMapping(value = "/getHcCrkPageList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "火车出入库记录查询", notes = "火车出入库记录查询，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "cazylx", value = "业务类型", paramType = "query"),
            @ApiImplicitParam(name = "pz", value = "品种 ", paramType = "query"),
            @ApiImplicitParam(name = "beginDate", value = "开始日期 ", paramType = "query"),
            @ApiImplicitParam(name = "endDate", value = "截止日期 ", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓号", paramType = "query"),
            @ApiImplicitParam(name = "warehouseId", value = "货位号 ", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
    })
    public PageInfo<Map<String, Object>> getHcCrkPageList(Integer pageNum, Integer pageSize,String cazylx, String pz,
              String beginDate, String endDate, String houseId,String warehouseId, Integer orgId) {
        Map<String, Object> map = new HashMap<String, Object>();
        if (null != cazylx && !"".equals(cazylx)) {
            if (cazylx.equals("1")) {
                map.put("ywlx", "火车入仓");
            } else if (cazylx.equals("3")) {
                map.put("ywlx", "火车出仓");
            }
        }
        if (null != pz && !"".equals(pz)) {
            map.put("lspz", pz);
        }
        if (beginDate != null && !"".equals(beginDate)) {
            map.put("startTime", beginDate+" 00:00:00");
        }
        if (endDate != null && !"".equals(endDate)) {
            map.put("endTime", endDate+" 23:59:59");
        }
        if (houseId != null && !"".equals(houseId)) {
            map.put("houseId", houseId);
        }
        if (warehouseId != null && !"".equals(warehouseId)) {
            map.put("wareId", warehouseId);
        }
        if (orgId != null && !"".equals(orgId)) {
            map.put("orgId", orgId);
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<Map<String, Object>> list = crkRecordService.queryHcCrkrecord(map);
        PageInfo<Map<String, Object>> pageInfo = new PageInfo<Map<String, Object>>(list);
        List<Map<String, Object>> page_list = ParameterMapUtil.slashCapitals(pageInfo.getList());
        pageInfo.setList(page_list);
        return pageInfo;
    }

    /**
     * 获取出入库记录详情以及质检信息
     *
     * @param bizNo 单据编号
     * @return
     */
    @RequestMapping(value = "/detail", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "获取出入库记录详情以及质检信息", notes = "出入库记录详情以及质检信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bizNo", value = "单据编号", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query"),
            @ApiImplicitParam(name = "ywlx", value = "业务类型", paramType = "query"),
            @ApiImplicitParam(name = "lspz", value = "粮食品种", paramType = "query")
    })
    public Map<String, Object> detail(String bizNo, Integer orgId, String ywlx, String lspz) {
        /**
         * 分为出库和入库
         * 基本信息
         * 包括：出入库流水单号、计划文件号、业务类型、出入库日期、仓房名称、货位名称、品种、数量（除了计划文件号之外，其它的从列表数据中取值）
         * 检验信息
         * 包括：跟出入库检验环节保存的化验数据一样
         * 称重信息
         * 包括：毛重、皮重、扣量、净重
         */

        /* 返回结果map大对象 */
        Map<String, Object> modelMap = new HashMap<String, Object>();

        /* 查询条件map对象 */
        Map<String, Object> conditionMap = new HashMap<String, Object>();
        conditionMap.put("ywlx", ywlx);
        if (null != bizNo && !"".equals(bizNo)) {
            conditionMap.put("bizNo", bizNo);
        }
        if (null != orgId) {
            conditionMap.put("orgId", orgId);
        }

        /* 查询出入库质检信息 */
        List<Map<String, Object>> zjxxMap = crkRecordService.queryJyxxNew(conditionMap);
        modelMap.put("zjxx", zjxxMap);
        if (null != lspz && !"".equals(lspz)) {
        	conditionMap.put("lspz", lspz);
        }
        String parent_id = crkRecordService.queryDataLspz(conditionMap);
        modelMap.put("parentId", parent_id);

        /* 查询出入库称重信息 */
        List<Map<String, Object>> czxx = crkRecordService.queryCzxx(conditionMap);
        if (null != czxx && czxx.size() > 0) {
            Map<String, Object> czxxMap = czxx.get(0);
            double xzzl = 0d;
            double jszl = 0d;
            String zkl = "";
            if (null != czxxMap.get("xzzl") && null != czxxMap.get("jszl")) {
                xzzl = (double) czxxMap.get("xzzl");
                jszl = (double) czxxMap.get("jszl");
                DecimalFormat df = new DecimalFormat("0.00");
                zkl = df.format(xzzl - jszl);
            }
            czxxMap.put("zkl", zkl);
            modelMap.put("czxx", czxxMap);
        }

        return modelMap;
    }

    /**
     * 出入库监管统计查询列表
     *
     * @param pageNum
     * @param pageSize
     * @param cazylx
     * @param pz
     * @param beginDate
     * @param endDate
     * @param houseId
     * @param warehouseId
     * @return
     */
    @RequestMapping(value = "/getCycleFoodCount", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "出入库监管统计查询", notes = "出入库监管统计查询，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "cazylx", value = "业务类型", paramType = "query"),
            @ApiImplicitParam(name = "pz", value = "品种 ", paramType = "query"),
            @ApiImplicitParam(name = "beginDate", value = "开始日期 ", paramType = "query"),
            @ApiImplicitParam(name = "endDate", value = "截止日期 ", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓号", paramType = "query")
    })
    public PageInfo<Map<String, Object>> getCycleFoodCount(Integer pageNum, Integer pageSize, String cazylx,
                                                           String orgId, String pz, String beginDate, String endDate, Integer houseId, Integer warehouseId) {
        Map<String, Object> map = new HashMap<>();
        if (StringUtils.isNotBlank(orgId))
            map.put("orgId", orgId);
        if (null != cazylx && !"".equals(cazylx)) {
            if (cazylx.equals("1")) {
                map.put("ywlx", "汽车入仓");
            } else if (cazylx.equals("3")) {
                map.put("ywlx", "汽车出仓");
            } else if (cazylx.equals("2")) {
                map.put("ywlx", "火车入仓");
            } else if (cazylx.equals("4")) {
                map.put("ywlx", "火车出仓");
            }
        }
        if (null != pz && !"".equals(pz)) {
            map.put("lspz", pz);
        }
        if (beginDate != null && !"".equals(beginDate)) {
            map.put("startTime", beginDate);
        }
        if (endDate != null && !"".equals(endDate)) {
            map.put("endTime", endDate);
        }
        if (houseId != null && !"".equals(houseId)) {
            map.put("houseId", houseId);
        }
        if (warehouseId != null && !"".equals(warehouseId)) {
            map.put("wareId", warehouseId);
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<Map<String, Object>> list = crkRecordService.queryCycleFoodCount(map);
        PageInfo<Map<String, Object>> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    @RequestMapping(value = "/getTrainDetail", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "获取火车出入库记录详情以及质检信息", notes = "火车出入库记录详情以及质检信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bizNo", value = "单据编号", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "单位ID", paramType = "query")
    })

    public Map<String, Object> getTrainDetail(String bizNo, Integer orgId) {
        /**
         * 分为出库和入库
         * 基本信息
         * 包括：出入库流水单号、计划文件号、业务类型、出入库日期、仓房名称、货位名称、品种、数量（除了计划文件号之外，其它的从列表数据中取值）
         * 检验信息
         * 包括：水分、色泽气味、杂质总量、容重、不完善粒总量、矿物质、品尝评分
         * 称重信息
         * 包括：毛重、皮重、扣量、净重
         */

        /* 返回结果map大对象 */
        Map<String, Object> modelMap = new HashMap<String, Object>();

        /* 查询条件map对象 */
        Map<String, Object> conditionMap = new HashMap<String, Object>();
        if (null != bizNo && !"".equals(bizNo)) {
            conditionMap.put("bizNo", bizNo);
        }
        if (null != orgId) {
            conditionMap.put("orgId", orgId);
        }

        /* 查询出入库质检信息 */
        Map<String, Object> zjxxMap = crkRecordService.queryTrainJyxx(conditionMap);
        if (null != zjxxMap && zjxxMap.size() > 0) {
            modelMap.put("zjxx", zjxxMap);
        } else {
            modelMap.put("zjxx", null);
        }

        /* 查询出入库称重信息 */
        Map<String, Object> czxxMap = crkRecordService.queryTrainCzxx(conditionMap);
        if (null != czxxMap && czxxMap.size() > 0) {
            double xzzl = 0d;
            double jszl = 0d;
            double zkl = 0d;
            if (null != czxxMap.get("xzzl") && null != czxxMap.get("jszl")) {
                xzzl = (double) czxxMap.get("xzzl");
                jszl = (double) czxxMap.get("jszl");
                zkl = xzzl - jszl;
            }
            czxxMap.put("zkl", zkl);
            modelMap.put("czxx", czxxMap);
        } else {
            modelMap.put("czxx", null);
        }

        return modelMap;
    }

    @RequestMapping(value = "/queryRkData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "入库记录查询", notes = "入库记录查询，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "粮库ID", paramType = "query")
    })
    public PageInfo<Map<String, Object>> queryRkData(Integer pageNum, Integer pageSize, String orgId) {
        Map<String, Object> map = new HashMap<String, Object>();
        if (orgId != null && !"".equals(orgId)) {
            map.put("orgId", orgId);
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<Map<String, Object>> list = crkRecordService.queryRkData(map);
        PageInfo<Map<String, Object>> pageInfo = new PageInfo<Map<String, Object>>(list);
        return pageInfo;
    }

    @RequestMapping(value = "/queryCkData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "出库记录查询", notes = "出库记录查询，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "粮库ID", paramType = "query")
    })
    public PageInfo<Map<String, Object>> queryCkData(Integer pageNum, Integer pageSize, String orgId) {
        Map<String, Object> map = new HashMap<String, Object>();
        if (orgId != null && !"".equals(orgId)) {
            map.put("orgId", orgId);
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<Map<String, Object>> list = crkRecordService.queryCkData(map);
        PageInfo<Map<String, Object>> pageInfo = new PageInfo<Map<String, Object>>(list);
        return pageInfo;
    }

    @RequestMapping(value="/queryQcCrkRecordData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="代储点查询汽车出入库记录", notes = "代储点查询汽车出入库记录")
	@ApiImplicitParams({
		@ApiImplicitParam(name="datas", value="条件", paramType="query")
	})
	public List<Map<String, Object>> queryQcCrkRecordData(String datas) {

    	ObjectMapper mapper = new ObjectMapper();
		List<Map<String, Object>> result_list = new ArrayList<Map<String, Object>>();

		DataKcglKcswDefault kcsw = null;
		Map<String, Object> param_map = null;
		List<Map<String, Object>> list = null;
		try {
			List<DataKcglKcswDefault> param_List = mapper.readValue(datas, new TypeReference<List<DataKcglKcswDefault>>(){});
			if (null != param_List && param_List.size() > 0) {
				for (DataKcglKcswDefault obj : param_List) {
					kcsw = obj;
					param_map = new HashMap<String, Object>();

					/* 单位 */
					if (null != kcsw.getUnitid()) {
						param_map.put("orgId", kcsw.getUnitid());
					}

					/* 货位 */
					if (null != kcsw.getHwh()) {
						param_map.put("wareId", kcsw.getHwh());
					}
					
					/* 时间 */
					if (null != kcsw.getModifydate()) {
						param_map.put("startTime", kcsw.getModifydate());
					}

					//example.setOrderByClause(" ModifyDate DESC");
					list = crkRecordService.queryAgentQcCrkrecord(param_map);

					//给生产年份赋值
					if (null != list && list.size() > 0) {
						Map<String, Object> obj1 = null;
						//for (Map<String, Object> obj1 : list) {
						for (int i = list.size()-1; i >= 0; i--) {
							//obj1.setOlddataid(ParameterUtil.date2string(obj1.get("")));
							obj1 = list.get(i);
							result_list.add(obj1);
						}
					}
				}
			}

		} catch (Exception e1) {
			e1.printStackTrace();
		}

		return result_list;
	}

    @RequestMapping(value="/queryHcCrkRecordData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="代储点查询火车出入库记录", notes = "代储点查询火车出入库记录")
	@ApiImplicitParams({
		@ApiImplicitParam(name="datas", value="条件", paramType="query")
	})
	public List<Map<String, Object>> queryHcCrkRecordData(String datas) {

		ObjectMapper mapper = new ObjectMapper();
		List<Map<String, Object>> result_list = new ArrayList<Map<String, Object>>();

		DataKcglKcswDefault kcsw = null;
		Map<String, Object> param_map = null;
		List<Map<String, Object>> list = null;
		try {
			List<DataKcglKcswDefault> param_List = mapper.readValue(datas, new TypeReference<List<DataKcglKcswDefault>>(){});
			if (null != param_List && param_List.size() > 0) {
				for (DataKcglKcswDefault obj : param_List) {
					kcsw = obj;
					param_map = new HashMap<String, Object>();

					/* 单位 */
					if (null != kcsw.getUnitid()) {
						param_map.put("orgId", kcsw.getUnitid());
					}

					/* 货位 */
					if (null != kcsw.getHwh()) {
						param_map.put("wareId", kcsw.getHwh());
					}

					//example.setOrderByClause(" ModifyDate DESC");
					list = crkRecordService.queryAgentHcCrkrecord(param_map);

					//给生产年份赋值
					if (null != list && list.size() > 0) {
						Map<String, Object> obj1 = null;
						for (int i = list.size()-1; i >= 0; i--) {
							//obj1.setOlddataid(ParameterUtil.date2string(obj1.get("")));
							obj1 = list.get(i);
							result_list.add(obj1);
						}
					}
				}
			}

		} catch (Exception e1) {
			e1.printStackTrace();
		}

		return result_list;
	}
}
