package com.chinaitop.agile.controller;


import java.util.*;

import javax.annotation.Resource;

import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.model.DataCrkywHcxzDefault;
import com.chinaitop.agile.model.DataCrkywHcxzFlt001;
import com.chinaitop.agile.service.HcxzService;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/agile/hcxz")
@Api(value= "HcxzController", description = "火车卸载信息控制类")
public class HcxzController {
	@Resource
	private HcxzService hcxzService;
	
	/**
	 * 查询火车列车卸载数据列表
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @return
	 */
	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="查询火车列车卸载数据列表", notes = "查询火车列车卸载数据列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query")
	})
    public PageInfo<DataCrkywHcxzDefault> getList(Integer pageNum, Integer pageSize) {
        List<DataCrkywHcxzDefault> list = hcxzService.queryByExample(pageNum, pageSize);  
        PageInfo<DataCrkywHcxzDefault> pageInfo = new PageInfo<DataCrkywHcxzDefault>(list);
        return pageInfo;
    }
	
	
	/**
	 * 查询到站入仓的数据(中转)列表
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @return
	 */
	@RequestMapping(value="/getZzList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="查询到站入仓的数据(中转)列表", notes = "查询到站入仓的数据(中转)列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query")
	})
	public PageInfo<DataCrkywHcxzDefault> getZzList(Integer pageNum, Integer pageSize,Integer orgId) {
		List<DataCrkywHcxzDefault> list = hcxzService.getZzList(pageNum, pageSize,orgId);  
		PageInfo<DataCrkywHcxzDefault> pageInfo = new PageInfo<DataCrkywHcxzDefault>(list);
		return pageInfo;
	}
	
		
	/**
     * 根据id查询一节火车皮的卸载信息(根据主表的编号查询字表)
     * @param dataId 主键
     * @return
     */
    @RequestMapping(value="/getData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="根据id查询一节火车皮的卸载信息(根据主表的编号查询字表)", notes = "根据id查询一节火车皮的卸载信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "dataId", value = "主键id", paramType = "query")
	})
    public List<DataCrkywHcxzFlt001> getDate(String dataId) {
    	List<DataCrkywHcxzFlt001> list = hcxzService.queryByDataId(dataId);
        return list;
    }
    
    
    

}
