package com.chinaitop.agile.controller;

import java.io.OutputStream;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.service.RegistrationService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/agile/registration")
@Api(value= "RegistrationController", description = "入库情况登统类")
public class RegistrationController {

	@Resource
	private RegistrationService registrationService;

    /**
     * 小麦入库情况数据
     * @param pageNum 页码
     * @param pageSize 每页条数
     * @param startDate 开始时间
     * @param endDate 结束时间
     * @return
     */
	@RequestMapping(value="/getWheatListPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value="条件查询小麦入库情况数据", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
        @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
        @ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
        @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
        @ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
		@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
    public PageInfo<Map<String,Object>> getWheatListPageInfo(HttpServletRequest request, Integer pageNum, Integer pageSize,
    		String houseId, String warehouseId, String startDate, String endDate, String orgId){
    	Map<String,Object> map = new HashMap<String,Object>();
    	PageInfo<Map<String,Object>> pageInfo = null;
		try {
			if (null != houseId && !"".equals(houseId)) {
				map.put("houseId", houseId);
			}
			if (null != warehouseId && !"".equals(warehouseId)) {
				map.put("warehouseId", warehouseId);
			}

			if (StringUtils.isNotBlank(orgId)) {
				map.put("orgId", orgId);
			}

			if (null != startDate && !"".equals(startDate)) {
				map.put("startDate", startDate);
			}
			if (null != endDate && !"".equals(endDate)) {
				map.put("endDate", endDate);
			}
			if(null != pageNum && null != pageSize){
				PageHelper.startPage(pageNum, pageSize);
			}
			List<Map<String,Object>> list = registrationService.getWheatListPageInfo(map);
			pageInfo = new PageInfo<Map<String,Object>>(list);
		} catch (Exception e) {
			e.printStackTrace();
		}
    	return pageInfo;
    }
	
	/**
	 * 玉米入库情况数据
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/getCornListPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件查询玉米入库情况数据", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
		@ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
		@ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
		@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
	public PageInfo<Map<String,Object>> getCornListPageInfo(HttpServletRequest request, Integer pageNum, Integer pageSize,
			String houseId, String warehouseId, String startDate, String endDate, String orgId){
		Map<String,Object> map = new HashMap<String,Object>();
		PageInfo<Map<String,Object>> pageInfo = null;
		try {
			if (null != houseId && !"".equals(houseId)) {
				map.put("houseId", houseId);
			}
			if (null != warehouseId && !"".equals(warehouseId)) {
				map.put("warehouseId", warehouseId);
			}

			if (StringUtils.isNotBlank(orgId)) {
				map.put("orgId", orgId);
			}

			if (null != startDate && !"".equals(startDate)) {
				map.put("startDate", startDate);
			}
			if (null != endDate && !"".equals(endDate)) {
				map.put("endDate", endDate);
			}
			if(null != pageNum && null != pageSize){
				PageHelper.startPage(pageNum, pageSize);
			}
			List<Map<String,Object>> list = registrationService.getCornListPageInfo(map);
			pageInfo = new PageInfo<Map<String,Object>>(list);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return pageInfo;
	}
	
	/**
	 * 大豆入库情况数据
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/getSoybeanListPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件查询大豆入库情况数据", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
		@ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
		@ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
		@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
	public PageInfo<Map<String,Object>> getSoybeanListPageInfo(HttpServletRequest request, Integer pageNum, Integer pageSize,
			String houseId, String warehouseId, String startDate, String endDate, String orgId){
		Map<String,Object> map = new HashMap<String,Object>();
		PageInfo<Map<String,Object>> pageInfo = null;
		try {
			if (null != houseId && !"".equals(houseId)) {
				map.put("houseId", houseId);
			}
			if (null != warehouseId && !"".equals(warehouseId)) {
				map.put("warehouseId", warehouseId);
			}
			
			if (StringUtils.isNotBlank(orgId)) {
				map.put("orgId", orgId);
			}
			
			if (null != startDate && !"".equals(startDate)) {
				map.put("startDate", startDate);
			}
			if (null != endDate && !"".equals(endDate)) {
				map.put("endDate", endDate);
			}
			if(null != pageNum && null != pageSize){
				PageHelper.startPage(pageNum, pageSize);
			}
			List<Map<String,Object>> list = registrationService.getSoybeanListPageInfo(map);
			pageInfo = new PageInfo<Map<String,Object>>(list);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return pageInfo;
	}
	
	/**
	 * 稻谷入库情况数据
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/getRiceListPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件查询稻谷入库情况数据", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
		@ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
		@ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
		@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
	public PageInfo<Map<String,Object>> getRiceListPageInfo(HttpServletRequest request, Integer pageNum, Integer pageSize,
			String houseId, String warehouseId, String startDate, String endDate, String orgId){
		Map<String,Object> map = new HashMap<String,Object>();
		PageInfo<Map<String,Object>> pageInfo = null;
		try {
			if (null != houseId && !"".equals(houseId)) {
				map.put("houseId", houseId);
			}
			if (null != warehouseId && !"".equals(warehouseId)) {
				map.put("warehouseId", warehouseId);
			}

			if (StringUtils.isNotBlank(orgId)) {
				map.put("orgId", orgId);
			}

			if (null != startDate && !"".equals(startDate)) {
				map.put("startDate", startDate);
			}
			if (null != endDate && !"".equals(endDate)) {
				map.put("endDate", endDate);
			}
			if(null != pageNum && null != pageSize){
				PageHelper.startPage(pageNum, pageSize);
			}
			List<Map<String,Object>> list = registrationService.getRiceListPageInfo(map);
			pageInfo = new PageInfo<Map<String,Object>>(list);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return pageInfo;
	}
	
	/**
	 * 大豆原油入库情况数据
	 * @param pageNum 页码
	 * @param pageSize 每页条数
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/getCrudeOilListPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件查询大豆原油入库情况数据", notes = "支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "tankId", value = "油罐id", paramType = "query"),
		@ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
		@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
	public PageInfo<Map<String,Object>> getCrudeOilListPageInfo(HttpServletRequest request, Integer pageNum, Integer pageSize,
			String tankId, String startDate, String endDate, String orgId){
		Map<String,Object> map = new HashMap<String,Object>();
		PageInfo<Map<String,Object>> pageInfo = null;
		try {
			if (null != tankId && !"".equals(tankId)) {
				map.put("tankId", tankId);
			}

			if (StringUtils.isNotBlank(orgId)) {
				map.put("orgId", orgId);
			}

			if (null != startDate && !"".equals(startDate)) {
				map.put("startDate", startDate);
			}
			if (null != endDate && !"".equals(endDate)) {
				map.put("endDate", endDate);
			}
			if(null != pageNum && null != pageSize){
				PageHelper.startPage(pageNum, pageSize);
			}
			List<Map<String,Object>> list = registrationService.getCrudeOilListPageInfo(map);
			pageInfo = new PageInfo<Map<String,Object>>(list);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return pageInfo;
	}

	/**
	 * 小麦入库情况数据
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/exportWheatListPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件导出小麦入库情况数据", notes = "条件查询和列表一致")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
			@ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
			@ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
			@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query"),
			@ApiImplicitParam(name = "zbr", value = "制表人", paramType = "query"),
			@ApiImplicitParam(name = "shdw", value = "收货单位", paramType = "query"),
			@ApiImplicitParam(name = "dwfzr", value = "单位负责人", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
	public void  exportWheatListPageInfo(HttpServletResponse response,HttpServletRequest request,
										 String houseId, String warehouseId, String startDate, String endDate,
										 String zbr, String shdw, String dwfzr, String orgId){
		Map<String,Object> map = new HashMap<String,Object>();
		try {
			if (null != houseId && !"".equals(houseId)) {
				map.put("houseId", houseId);
			}
			if (null != warehouseId && !"".equals(warehouseId)) {
				map.put("warehouseId", warehouseId);
			}

			if (StringUtils.isNotBlank(orgId)) {
				map.put("orgId", orgId);
			}

			if (null != startDate && !"".equals(startDate)) {
				map.put("startDate", startDate);
			}
			if (null != endDate && !"".equals(endDate)) {
				map.put("endDate", endDate);
			}
			List<Map<String,Object>> list = registrationService.getWheatListPageInfo(map);
			HSSFWorkbook workbook = registrationService.wheatdataTransfor(list,zbr,shdw,dwfzr);
			String fileName = "小麦登统表";
			// 获取输出流
			OutputStream os = response.getOutputStream();
			// 重置输出流
			response.reset();
			// 设定输出文件头
			response.setHeader("Content-disposition", "attachment; filename=" + new String(fileName.getBytes("GB2312"), "8859_1") + ".xlsx");
			//name属性设置和跨服访问有关
			response.setHeader("Access-Control-Allow-Origin", "*");
			// 定义输出内容类型
			response.setContentType("application/vnd.ms-excel;charset=gb2312");

			workbook.write(os);
			//关闭流
			os.close();
			return;
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * 稻谷入库情况数据
	 * @param startDate 开始时间
	 * @param endDate 结束时间
	 * @return
	 */
	@RequestMapping(value="/exportRiceListPageInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件导出稻谷入库情况数据", notes = "条件查询和列表一致")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "houseId", value = "仓房id", paramType = "query"),
			@ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "query"),
			@ApiImplicitParam(name = "startDate", value = "开始时间", paramType = "query"),
			@ApiImplicitParam(name = "endDate", value = "结束时间", paramType = "query"),
			@ApiImplicitParam(name = "zbr", value = "制表人", paramType = "query"),
			@ApiImplicitParam(name = "shdw", value = "收货单位", paramType = "query"),
			@ApiImplicitParam(name = "dwfzr", value = "单位负责人", paramType = "query"),
			@ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query")
	})
	public void exportRiceListPageInfo(HttpServletResponse response,HttpServletRequest request,
															String houseId, String warehouseId, String startDate, String endDate,
									   String zbr, String shdw, String dwfzr, String orgId){
		Map<String,Object> map = new HashMap<String,Object>();
		try {
			if (null != houseId && !"".equals(houseId)) {
				map.put("houseId", houseId);
			}
			if (null != warehouseId && !"".equals(warehouseId)) {
				map.put("warehouseId", warehouseId);
			}

			if (StringUtils.isNotBlank(orgId)) {
				map.put("orgId", orgId);
			}

			if (null != startDate && !"".equals(startDate)) {
				map.put("startDate", startDate);
			}
			if (null != endDate && !"".equals(endDate)) {
				map.put("endDate", endDate);
			}
			List<Map<String,Object>> list = registrationService.getRiceListPageInfo(map);
			HSSFWorkbook workbook = registrationService.ricedataTransfor(list,zbr,shdw,dwfzr);
			String fileName = "稻谷登统表";
			// 获取输出流
			OutputStream os = response.getOutputStream();
			// 重置输出流
			response.reset();
			// 设定输出文件头
			response.setHeader("Content-disposition", "attachment; filename=" + new String(fileName.getBytes("GB2312"), "8859_1") + ".xlsx");
			//name属性设置和跨服访问有关
			response.setHeader("Access-Control-Allow-Origin", "*");
			// 定义输出内容类型
			response.setContentType("application/vnd.ms-excel;charset=gb2312");
			workbook.write(os);
			//关闭流
			os.close();
			return;
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	@RequestMapping(value="/test", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="测试")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "orgId", value = "组织机构id", paramType = "query")
	})
	public List<Map<String, Object>> test(String orgId){
		List<Map<String, Object>> list = null;
		try {
			//list = registrationService.test(orgId);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return list;
	}
}
